@@ -49,8 +49,8 @@ func doMain(m *testing.M, cleanup bool) (int, error) {
 		return 0, fmt.Errorf("could not connect to docker: %w", err)
 	}
 	db.res, err = pool.RunWithOptions(&dt.RunOptions{
-		Repository: "yandex/clickhouse-server",
-		Tag:        "latest",
+		Repository: "clickhouse/clickhouse-server",
+		Tag:        "22.7",
 		Mounts:     []string{filepath.Join(dir, "testdata") + ":/docker-entrypoint-initdb.d"},
 	})
 	if err != nil {
@@ -85,7 +85,7 @@ func TestSchemas(t *testing.T) {
 	if err != nil {
 		t.Fatalf("could not read schemas: %v", err)
 	}
-	checkNames(t, "schema", res, "default", "system", "tutorial")
+	checkNames(t, "schema", res, "default", "system", "tutorial", "tutorial_unexpected", "INFORMATION_SCHEMA", "information_schema")
 }
 
 func TestTables(t *testing.T) {
@@ -137,6 +137,11 @@ func checkNames(t *testing.T, typ string, res interface{ Next() bool }, exp ...s
 			t.Errorf("missing %s %q", typ, name)
 		}
 	}
+	for name := range names {
+		if _, ok := n[name]; !ok {
+			t.Errorf("unexpected %s %q", typ, name)
+		}
+	}
 }
 
 func getName(res interface{}) string {
@@ -184,15 +189,20 @@ func funcNames() []string {
 		"IPv4NumToString",
 		"IPv4NumToStringClassC",
 		"IPv4StringToNum",
+		"IPv4StringToNumOrDefault",
+		"IPv4StringToNumOrNull",
 		"IPv4ToIPv6",
 		"IPv6CIDRToRange",
 		"IPv6NumToString",
 		"IPv6StringToNum",
+		"IPv6StringToNumOrDefault",
+		"IPv6StringToNumOrNull",
 		"JSONExtract",
 		"JSONExtractArrayRaw",
 		"JSONExtractBool",
 		"JSONExtractFloat",
 		"JSONExtractInt",
+		"JSONExtractKeys",
 		"JSONExtractKeysAndValues",
 		"JSONExtractKeysAndValuesRaw",
 		"JSONExtractRaw",
@@ -202,19 +212,43 @@ func funcNames() []string {
 		"JSONKey",
 		"JSONLength",
 		"JSONType",
+		"JSON_EXISTS",
+		"JSON_QUERY",
+		"JSON_VALUE",
+		"L1Distance",
+		"L1Norm",
+		"L1Normalize",
+		"L2Distance",
+		"L2Norm",
+		"L2Normalize",
+		"L2SquaredDistance",
+		"L2SquaredNorm",
+		"LAST_DAY",
+		"LinfDistance",
+		"LinfNorm",
+		"LinfNormalize",
+		"LpDistance",
+		"LpNorm",
+		"LpNormalize",
 		"MACNumToString",
 		"MACStringToNum",
 		"MACStringToOUI",
+		"MD4",
 		"MD5",
 		"MINUTE",
 		"MONTH",
 		"QUARTER",
+		"REGEXP_MATCHES",
+		"REGEXP_REPLACE",
 		"SECOND",
 		"SHA1",
 		"SHA224",
 		"SHA256",
+		"SHA384",
+		"SHA512",
 		"STDDEV_POP",
 		"STDDEV_SAMP",
+		"SVG",
 		"TO_BASE64",
 		"URLHash",
 		"URLHierarchy",
@@ -224,6 +258,7 @@ func funcNames() []string {
 		"VAR_POP",
 		"VAR_SAMP",
 		"YEAR",
+		"_CAST",
 		"__bitBoolMaskAnd",
 		"__bitBoolMaskOr",
 		"__bitSwapLastTwo",
@@ -231,18 +266,25 @@ func funcNames() []string {
 		"__getScalar",
 		"abs",
 		"accurateCast",
+		"accurateCastOrDefault",
 		"accurateCastOrNull",
+		"accurate_Cast",
+		"accurate_CastOrNull",
 		"acos",
 		"acosh",
 		"addDays",
 		"addHours",
+		"addMicroseconds",
+		"addMilliseconds",
 		"addMinutes",
 		"addMonths",
+		"addNanoseconds",
 		"addQuarters",
 		"addSeconds",
 		"addWeeks",
 		"addYears",
 		"addressToLine",
+		"addressToLineWithInlines",
 		"addressToSymbol",
 		"aes_decrypt_mysql",
 		"aes_encrypt_mysql",
@@ -277,9 +319,13 @@ func funcNames() []string {
 		"arrayFilter",
 		"arrayFirst",
 		"arrayFirstIndex",
+		"arrayFirstOrNull",
 		"arrayFlatten",
 		"arrayIntersect",
 		"arrayJoin",
+		"arrayLast",
+		"arrayLastIndex",
+		"arrayLastOrNull",
 		"arrayMap",
 		"arrayMax",
 		"arrayMin",
@@ -312,10 +358,12 @@ func funcNames() []string {
 		"avg",
 		"avgWeighted",
 		"bar",
+		"base58Decode",
+		"base58Encode",
 		"base64Decode",
 		"base64Encode",
 		"basename",
-		"bayesAB",
+		"bin",
 		"bitAnd",
 		"bitCount",
 		"bitHammingDistance",
@@ -326,6 +374,7 @@ func funcNames() []string {
 		"bitRotateRight",
 		"bitShiftLeft",
 		"bitShiftRight",
+		"bitSlice",
 		"bitTest",
 		"bitTestAll",
 		"bitTestAny",
@@ -372,11 +421,13 @@ func funcNames() []string {
 		"concatAssumeInjective",
 		"connectionId",
 		"connection_id",
+		"contingency",
 		"convertCharset",
 		"corr",
 		"corrStable",
 		"cos",
 		"cosh",
+		"cosineDistance",
 		"count",
 		"countDigits",
 		"countEqual",
@@ -389,7 +440,11 @@ func funcNames() []string {
 		"covarPopStable",
 		"covarSamp",
 		"covarSampStable",
+		"cramersV",
+		"cramersVBiasCorrected",
 		"currentDatabase",
+		"currentProfiles",
+		"currentRoles",
 		"currentUser",
 		"cutFragment",
 		"cutIPv6",
@@ -403,17 +458,29 @@ func funcNames() []string {
 		"cutWWW",
 		"dateDiff",
 		"dateName",
+		"dateTime64ToSnowflake",
+		"dateTimeToSnowflake",
 		"dateTrunc",
 		"date_trunc",
 		"decodeURLComponent",
+		"decodeURLFormComponent",
 		"decodeXMLComponent",
 		"decrypt",
+		"defaultProfiles",
+		"defaultRoles",
 		"defaultValueOfArgumentType",
 		"defaultValueOfTypeName",
+		"degrees",
 		"deltaSum",
 		"deltaSumTimestamp",
 		"demangle",
 		"dense_rank",
+		"detectCharset",
+		"detectLanguage",
+		"detectLanguageMixed",
+		"detectLanguageUnknown",
+		"detectProgrammingLanguage",
+		"detectTonality",
 		"dictGet",
 		"dictGetChildren",
 		"dictGetDate",
@@ -450,9 +517,15 @@ func funcNames() []string {
 		"dictGetUUIDOrDefault",
 		"dictHas",
 		"dictIsIn",
+		"distanceL1",
+		"distanceL2",
+		"distanceL2Squared",
+		"distanceLinf",
+		"distanceLp",
 		"divide",
 		"domain",
 		"domainWithoutWWW",
+		"dotProduct",
 		"dumpColumnStructure",
 		"e",
 		"empty",
@@ -470,6 +543,10 @@ func funcNames() []string {
 		"emptyArrayUInt32",
 		"emptyArrayUInt64",
 		"emptyArrayUInt8",
+		"enabledProfiles",
+		"enabledRoles",
+		"encodeURLComponent",
+		"encodeURLFormComponent",
 		"encodeXMLComponent",
 		"encrypt",
 		"endsWith",
@@ -482,6 +559,11 @@ func funcNames() []string {
 		"exp",
 		"exp10",
 		"exp2",
+		"exponentialMovingAverage",
+		"exponentialTimeDecayedAvg",
+		"exponentialTimeDecayedCount",
+		"exponentialTimeDecayedMax",
+		"exponentialTimeDecayedSum",
 		"extract",
 		"extractAll",
 		"extractAllGroups",
@@ -503,6 +585,7 @@ func funcNames() []string {
 		"firstSignificantSubdomainCustom",
 		"first_value",
 		"flatten",
+		"flattenTuple",
 		"floor",
 		"format",
 		"formatDateTime",
@@ -525,12 +608,16 @@ func funcNames() []string {
 		"generateUUIDv4",
 		"geoDistance",
 		"geoToH3",
+		"geoToS2",
 		"geohashDecode",
 		"geohashEncode",
 		"geohashesInBox",
 		"getMacro",
+		"getOSKernelVersion",
+		"getServerPort",
 		"getSetting",
 		"getSizeOfEnumType",
+		"getTypeSerializationStreams",
 		"globalIn",
 		"globalInIgnoreSet",
 		"globalNotIn",
@@ -558,16 +645,45 @@ func funcNames() []string {
 		"groupBitmapOr",
 		"groupBitmapXor",
 		"groupUniqArray",
+		"h3CellAreaM2",
+		"h3CellAreaRads2",
+		"h3Distance",
 		"h3EdgeAngle",
+		"h3EdgeLengthKm",
 		"h3EdgeLengthM",
+		"h3ExactEdgeLengthKm",
+		"h3ExactEdgeLengthM",
+		"h3ExactEdgeLengthRads",
 		"h3GetBaseCell",
+		"h3GetDestinationIndexFromUnidirectionalEdge",
+		"h3GetFaces",
+		"h3GetIndexesFromUnidirectionalEdge",
+		"h3GetOriginIndexFromUnidirectionalEdge",
+		"h3GetPentagonIndexes",
+		"h3GetRes0Indexes",
 		"h3GetResolution",
+		"h3GetUnidirectionalEdge",
+		"h3GetUnidirectionalEdgeBoundary",
+		"h3GetUnidirectionalEdgesFromHexagon",
+		"h3HexAreaKm2",
 		"h3HexAreaM2",
+		"h3HexRing",
 		"h3IndexesAreNeighbors",
+		"h3IsPentagon",
+		"h3IsResClassIII",
 		"h3IsValid",
+		"h3Line",
+		"h3NumHexagons",
+		"h3PointDistKm",
+		"h3PointDistM",
+		"h3PointDistRads",
+		"h3ToCenterChild",
 		"h3ToChildren",
+		"h3ToGeo",
+		"h3ToGeoBoundary",
 		"h3ToParent",
 		"h3ToString",
+		"h3UnidirectionalEdgeIsValid",
 		"h3kRing",
 		"halfMD5",
 		"has",
@@ -578,9 +694,13 @@ func funcNames() []string {
 		"hasThreadFuzzer",
 		"hasToken",
 		"hasTokenCaseInsensitive",
+		"hashid",
 		"hex",
 		"histogram",
 		"hiveHash",
+		"hop",
+		"hopEnd",
+		"hopStart",
 		"hostName",
 		"hostname",
 		"hypot",
@@ -594,6 +714,8 @@ func funcNames() []string {
 		"inIgnoreSet",
 		"indexHint",
 		"indexOf",
+		"initialQueryID",
+		"initial_query_id",
 		"initializeAggregation",
 		"intDiv",
 		"intDivOrZero",
@@ -612,6 +734,7 @@ func funcNames() []string {
 		"isNaN",
 		"isNotNull",
 		"isNull",
+		"isNullable",
 		"isValidJSON",
 		"isValidUTF8",
 		"isZeroOrNull",
@@ -620,6 +743,7 @@ func funcNames() []string {
 		"joinGet",
 		"joinGetOrNull",
 		"jumpConsistentHash",
+		"kostikConsistentHash",
 		"kurtPop",
 		"kurtSamp",
 		"lagInFrame",
@@ -628,6 +752,11 @@ func funcNames() []string {
 		"lcm",
 		"leadInFrame",
 		"least",
+		"left",
+		"leftPad",
+		"leftPadUTF8",
+		"leftUTF8",
+		"lemmatize",
 		"length",
 		"lengthUTF8",
 		"less",
@@ -645,22 +774,36 @@ func funcNames() []string {
 		"lowCardinalityKeys",
 		"lower",
 		"lowerUTF8",
+		"lpad",
+		"makeDate",
+		"makeDate32",
+		"makeDateTime",
+		"makeDateTime64",
 		"mannWhitneyUTest",
 		"map",
 		"mapAdd",
+		"mapApply",
 		"mapContains",
+		"mapContainsKeyLike",
+		"mapExtractKeyLike",
+		"mapFilter",
 		"mapKeys",
 		"mapPopulateSeries",
 		"mapSubtract",
+		"mapUpdate",
 		"mapValues",
 		"match",
 		"materialize",
 		"max",
+		"max2",
 		"maxIntersections",
 		"maxIntersectionsPosition",
 		"maxMap",
+		"maxMappedArrays",
+		"meanZTest",
 		"median",
 		"medianBFloat16",
+		"medianBFloat16Weighted",
 		"medianDeterministic",
 		"medianExact",
 		"medianExactHigh",
@@ -670,16 +813,22 @@ func funcNames() []string {
 		"medianTDigestWeighted",
 		"medianTiming",
 		"medianTimingWeighted",
+		"meiliMatch",
 		"metroHash64",
 		"mid",
 		"min",
+		"min2",
 		"minMap",
+		"minMappedArrays",
+		"minSampleSizeContinous",
+		"minSampleSizeConversion",
 		"minus",
 		"mod",
 		"modelEvaluate",
 		"modulo",
 		"moduloLegacy",
 		"moduloOrZero",
+		"monthName",
 		"multiFuzzyMatchAllIndices",
 		"multiFuzzyMatchAny",
 		"multiFuzzyMatchAnyIndex",
@@ -732,8 +881,23 @@ func funcNames() []string {
 		"ngramSimHashCaseInsensitive",
 		"ngramSimHashCaseInsensitiveUTF8",
 		"ngramSimHashUTF8",
+		"ngrams",
+		"nonNegativeDerivative",
+		"normL1",
+		"normL2",
+		"normL2Squared",
+		"normLinf",
+		"normLp",
+		"normalizeL1",
+		"normalizeL2",
+		"normalizeLinf",
+		"normalizeLp",
 		"normalizeQuery",
 		"normalizeQueryKeepNames",
+		"normalizeUTF8NFC",
+		"normalizeUTF8NFD",
+		"normalizeUTF8NFKC",
+		"normalizeUTF8NFKD",
 		"normalizedQueryHash",
 		"normalizedQueryHashKeepNames",
 		"not",
@@ -745,8 +909,10 @@ func funcNames() []string {
 		"notLike",
 		"notNullIn",
 		"notNullInIgnoreSet",
+		"nothing",
 		"now",
 		"now64",
+		"nth_value",
 		"nullIf",
 		"nullIn",
 		"nullInIgnoreSet",
@@ -763,6 +929,7 @@ func funcNames() []string {
 		"parseDateTimeBestEffortUS",
 		"parseDateTimeBestEffortUSOrNull",
 		"parseDateTimeBestEffortUSOrZero",
+		"parseTimeDelta",
 		"partitionId",
 		"path",
 		"pathFull",
@@ -793,9 +960,11 @@ func funcNames() []string {
 		"positionUTF8",
 		"pow",
 		"power",
+		"proportionsZTest",
 		"protocol",
 		"quantile",
 		"quantileBFloat16",
+		"quantileBFloat16Weighted",
 		"quantileDeterministic",
 		"quantileExact",
 		"quantileExactExclusive",
@@ -809,6 +978,7 @@ func funcNames() []string {
 		"quantileTimingWeighted",
 		"quantiles",
 		"quantilesBFloat16",
+		"quantilesBFloat16Weighted",
 		"quantilesDeterministic",
 		"quantilesExact",
 		"quantilesExactExclusive",
@@ -820,8 +990,11 @@ func funcNames() []string {
 		"quantilesTDigestWeighted",
 		"quantilesTiming",
 		"quantilesTimingWeighted",
+		"queryID",
 		"queryString",
 		"queryStringAndFragment",
+		"query_id",
+		"radians",
 		"rand",
 		"rand32",
 		"rand64",
@@ -833,10 +1006,10 @@ func funcNames() []string {
 		"range",
 		"rank",
 		"rankCorr",
-		"readWktMultiPolygon",
-		"readWktPoint",
-		"readWktPolygon",
-		"readWktRing",
+		"readWKTMultiPolygon",
+		"readWKTPoint",
+		"readWKTPolygon",
+		"readWKTRing",
 		"regexpQuoteMeta",
 		"regionHierarchy",
 		"regionIn",
@@ -878,6 +1051,11 @@ func funcNames() []string {
 		"retention",
 		"reverse",
 		"reverseUTF8",
+		"revision",
+		"right",
+		"rightPad",
+		"rightPadUTF8",
+		"rightUTF8",
 		"round",
 		"roundAge",
 		"roundBankers",
@@ -887,13 +1065,28 @@ func funcNames() []string {
 		"rowNumberInAllBlocks",
 		"rowNumberInBlock",
 		"row_number",
+		"rpad",
 		"runningAccumulate",
 		"runningConcurrency",
 		"runningDifference",
 		"runningDifferenceStartingWithFirstValue",
+		"s2CapContains",
+		"s2CapUnion",
+		"s2CellsIntersect",
+		"s2GetNeighbors",
+		"s2RectAdd",
+		"s2RectContains",
+		"s2RectIntersection",
+		"s2RectUnion",
+		"s2ToGeo",
+		"scalarProduct",
 		"sequenceCount",
 		"sequenceMatch",
 		"sequenceNextNode",
+		"serverUUID",
+		"shardCount",
+		"shardNum",
+		"showCertificate",
 		"sigmoid",
 		"sign",
 		"simpleJSONExtractBool",
@@ -905,6 +1098,7 @@ func funcNames() []string {
 		"simpleJSONHas",
 		"simpleLinearRegression",
 		"sin",
+		"singleValueOrNull",
 		"sinh",
 		"sipHash128",
 		"sipHash64",
@@ -912,26 +1106,36 @@ func funcNames() []string {
 		"skewSamp",
 		"sleep",
 		"sleepEachRow",
+		"snowflakeToDateTime",
+		"snowflakeToDateTime64",
+		"sparkbar",
 		"splitByChar",
+		"splitByNonAlpha",
 		"splitByRegexp",
 		"splitByString",
+		"splitByWhitespace",
 		"sqrt",
 		"startsWith",
 		"stddevPop",
 		"stddevPopStable",
 		"stddevSamp",
 		"stddevSampStable",
+		"stem",
 		"stochasticLinearRegression",
 		"stochasticLogisticRegression",
 		"stringToH3",
 		"studentTTest",
+		"subBitmap",
 		"substr",
 		"substring",
 		"substringUTF8",
 		"subtractDays",
 		"subtractHours",
+		"subtractMicroseconds",
+		"subtractMilliseconds",
 		"subtractMinutes",
 		"subtractMonths",
+		"subtractNanoseconds",
 		"subtractQuarters",
 		"subtractSeconds",
 		"subtractWeeks",
@@ -943,12 +1147,15 @@ func funcNames() []string {
 		"sumMapFiltered",
 		"sumMapFilteredWithOverflow",
 		"sumMapWithOverflow",
+		"sumMappedArrays",
 		"sumWithOverflow",
 		"svg",
+		"synonyms",
 		"tan",
 		"tanh",
 		"tcpPort",
 		"tgamma",
+		"theilsU",
 		"throwIf",
 		"tid",
 		"timeSlot",
@@ -959,71 +1166,99 @@ func funcNames() []string {
 		"timezone",
 		"timezoneOf",
 		"timezoneOffset",
+		"toBool",
 		"toColumnTypeName",
 		"toDate",
+		"toDate32",
+		"toDate32OrDefault",
+		"toDate32OrNull",
+		"toDate32OrZero",
+		"toDateOrDefault",
 		"toDateOrNull",
 		"toDateOrZero",
 		"toDateTime",
 		"toDateTime32",
 		"toDateTime64",
+		"toDateTime64OrDefault",
 		"toDateTime64OrNull",
 		"toDateTime64OrZero",
+		"toDateTimeOrDefault",
 		"toDateTimeOrNull",
 		"toDateTimeOrZero",
 		"toDayOfMonth",
 		"toDayOfWeek",
 		"toDayOfYear",
 		"toDecimal128",
+		"toDecimal128OrDefault",
 		"toDecimal128OrNull",
 		"toDecimal128OrZero",
 		"toDecimal256",
+		"toDecimal256OrDefault",
 		"toDecimal256OrNull",
 		"toDecimal256OrZero",
 		"toDecimal32",
+		"toDecimal32OrDefault",
 		"toDecimal32OrNull",
 		"toDecimal32OrZero",
 		"toDecimal64",
+		"toDecimal64OrDefault",
 		"toDecimal64OrNull",
 		"toDecimal64OrZero",
 		"toFixedString",
 		"toFloat32",
+		"toFloat32OrDefault",
 		"toFloat32OrNull",
 		"toFloat32OrZero",
 		"toFloat64",
+		"toFloat64OrDefault",
 		"toFloat64OrNull",
 		"toFloat64OrZero",
 		"toHour",
 		"toIPv4",
+		"toIPv4OrDefault",
+		"toIPv4OrNull",
 		"toIPv6",
+		"toIPv6OrDefault",
+		"toIPv6OrNull",
 		"toISOWeek",
 		"toISOYear",
 		"toInt128",
+		"toInt128OrDefault",
 		"toInt128OrNull",
 		"toInt128OrZero",
 		"toInt16",
+		"toInt16OrDefault",
 		"toInt16OrNull",
 		"toInt16OrZero",
 		"toInt256",
+		"toInt256OrDefault",
 		"toInt256OrNull",
 		"toInt256OrZero",
 		"toInt32",
+		"toInt32OrDefault",
 		"toInt32OrNull",
 		"toInt32OrZero",
 		"toInt64",
+		"toInt64OrDefault",
 		"toInt64OrNull",
 		"toInt64OrZero",
 		"toInt8",
+		"toInt8OrDefault",
 		"toInt8OrNull",
 		"toInt8OrZero",
 		"toIntervalDay",
 		"toIntervalHour",
+		"toIntervalMicrosecond",
+		"toIntervalMillisecond",
 		"toIntervalMinute",
 		"toIntervalMonth",
+		"toIntervalNanosecond",
 		"toIntervalQuarter",
 		"toIntervalSecond",
 		"toIntervalWeek",
 		"toIntervalYear",
 		"toJSONString",
+		"toLastDayOfMonth",
 		"toLowCardinality",
 		"toMinute",
 		"toModifiedJulianDay",
@@ -1044,11 +1279,15 @@ func funcNames() []string {
 		"toStartOfDay",
 		"toStartOfFifteenMinutes",
 		"toStartOfFiveMinute",
+		"toStartOfFiveMinutes",
 		"toStartOfHour",
 		"toStartOfISOYear",
 		"toStartOfInterval",
+		"toStartOfMicrosecond",
+		"toStartOfMillisecond",
 		"toStartOfMinute",
 		"toStartOfMonth",
+		"toStartOfNanosecond",
 		"toStartOfQuarter",
 		"toStartOfSecond",
 		"toStartOfTenMinutes",
@@ -1064,21 +1303,27 @@ func funcNames() []string {
 		"toUInt128OrNull",
 		"toUInt128OrZero",
 		"toUInt16",
+		"toUInt16OrDefault",
 		"toUInt16OrNull",
 		"toUInt16OrZero",
 		"toUInt256",
+		"toUInt256OrDefault",
 		"toUInt256OrNull",
 		"toUInt256OrZero",
 		"toUInt32",
+		"toUInt32OrDefault",
 		"toUInt32OrNull",
 		"toUInt32OrZero",
 		"toUInt64",
+		"toUInt64OrDefault",
 		"toUInt64OrNull",
 		"toUInt64OrZero",
 		"toUInt8",
+		"toUInt8OrDefault",
 		"toUInt8OrNull",
 		"toUInt8OrZero",
 		"toUUID",
+		"toUUIDOrDefault",
 		"toUUIDOrNull",
 		"toUUIDOrZero",
 		"toUnixTimestamp",
@@ -1093,20 +1338,38 @@ func funcNames() []string {
 		"toYear",
 		"toYearWeek",
 		"today",
+		"tokens",
 		"topK",
 		"topKWeighted",
 		"topLevelDomain",
+		"transactionID",
+		"transactionLatestSnapshot",
+		"transactionOldestSnapshot",
 		"transform",
+		"translate",
+		"translateUTF8",
 		"trimBoth",
 		"trimLeft",
 		"trimRight",
 		"trunc",
 		"truncate",
 		"tryBase64Decode",
+		"tumble",
+		"tumbleEnd",
+		"tumbleStart",
 		"tuple",
+		"tupleDivide",
+		"tupleDivideByNumber",
 		"tupleElement",
 		"tupleHammingDistance",
+		"tupleMinus",
+		"tupleMultiply",
+		"tupleMultiplyByNumber",
+		"tupleNegate",
+		"tuplePlus",
+		"tupleToNameValuePairs",
 		"ucase",
+		"unbin",
 		"unhex",
 		"uniq",
 		"uniqCombined",
@@ -1124,6 +1387,8 @@ func funcNames() []string {
 		"varPopStable",
 		"varSamp",
 		"varSampStable",
+		"vectorDifference",
+		"vectorSum",
 		"version",
 		"visibleWidth",
 		"visitParamExtractBool",
@@ -1136,6 +1401,7 @@ func funcNames() []string {
 		"week",
 		"welchTTest",
 		"windowFunnel",
+		"windowID",
 		"wkt",
 		"wordShingleMinHash",
 		"wordShingleMinHashArg",
@@ -1149,12 +1415,14 @@ func funcNames() []string {
 		"wordShingleSimHashCaseInsensitive",
 		"wordShingleSimHashCaseInsensitiveUTF8",
 		"wordShingleSimHashUTF8",
+		"wyHash64",
 		"xor",
 		"xxHash32",
 		"xxHash64",
 		"yandexConsistentHash",
 		"yearweek",
 		"yesterday",
+		"zookeeperSessionUptime",
 	}
 }
 
